@@ -24,22 +24,23 @@
 #ifndef _HTMLENGINE_H_
 #define _HTMLENGINE_H_
 
+#include <glib-object.h>
 #include <gdk/gdktypes.h>
-#include <gtk/gtkobject.h>
 #include <gtk/gtkwidget.h>
 #include "gtkhtml-types.h"
 
 #include "htmltypes.h"
 #include "htmlenums.h"
 #include "htmlcursor.h"
-#include "htmlfontmanager.h"
 
+
 #define HTML_TYPE_ENGINE                 (html_engine_get_type ())
-#define HTML_ENGINE(obj)                 (GTK_CHECK_CAST ((obj), HTML_TYPE_ENGINE, HTMLEngine))
-#define HTML_ENGINE_CLASS(klass)         (GTK_CHECK_CLASS_CAST ((klass), HTML_TYPE_ENGINE, HTMLEngineClass))
-#define HTML_IS_ENGINE(obj)              (GTK_CHECK_TYPE ((obj), HTML_TYPE_ENGINE))
-#define HTML_IS_ENGINE_CLASS(klass)      (GTK_CHECK_CLASS_TYPE ((klass), HTML_TYPE_ENGINE))
+#define HTML_ENGINE(obj)                 (G_TYPE_CHECK_INSTANCE_CAST ((obj), HTML_TYPE_ENGINE, HTMLEngine))
+#define HTML_ENGINE_CLASS(klass)         (G_TYPE_CHECK_CLASS_CAST ((klass), HTML_TYPE_ENGINE, HTMLEngineClass))
+#define HTML_IS_ENGINE(obj)              (G_TYPE_CHECK_INSTANCE_TYPE ((obj), HTML_TYPE_ENGINE))
+#define HTML_IS_ENGINE_CLASS(klass)      (G_TYPE_CHECK_CLASS_TYPE ((klass), HTML_TYPE_ENGINE))
 
+
 /* FIXME extreme hideous ugliness in the following lines.  */
 
 #define LEFT_BORDER 10
@@ -50,7 +51,7 @@
 /* FIXME this needs splitting.  */
 
 struct _HTMLEngine {
-	GtkObject parent;
+	GObject parent;
 	HTMLDrawQueue *draw_queue;
 
 	HTMLPainter *painter;
@@ -69,6 +70,9 @@ struct _HTMLEngine {
 	guint       clipboard_len;
 	GList      *clipboard_stack;
 
+	HTMLObject *primary;
+	guint       primary_len;
+
 	/* Freeze counter.  When greater than zero, we never trigger relayouts
            nor repaints.  When going from nonzero to zero, we relayout and
            repaint everything.  */
@@ -116,11 +120,7 @@ struct _HTMLEngine {
 	gboolean newPage;
 	gboolean begin;
  
-	GtkHTMLFontStyle font_style;
-	gint font_style_attrs [GTK_HTML_FONT_STYLE_SHIFT_LAST - GTK_HTML_FONT_STYLE_SHIFT_FIRST + 1];
-	HTMLStack *font_size_stack;
-	HTMLStack *font_face_stack;
-	HTMLStack *color_stack;	/* Color stack, elements are GdkColors.  */
+	HTMLStack *span_stack;
 	HTMLStack *clueflow_style_stack; /* Clueflow style stack, elements are HTMLClueFlowStyles.  */
 	HTMLStack *frame_stack;
 	HTMLStack *body_stack;
@@ -157,8 +157,6 @@ struct _HTMLEngine {
 
         gpointer image_factory;
 
-	HTMLStack *glossaryStack; /* HTMLGlossaryEntry */
-
 	/*
 	 * This list holds strings which are displayed in the view,
 	 * but are not actually contained in the HTML source.
@@ -270,16 +268,17 @@ struct _HTMLEngine {
 
 	gboolean save_data;
 	gint saved_step_count;
+
+	gboolean expose;
+	gboolean need_update;
 };
 
 /* must be forward referenced *sigh* */
 struct _HTMLEmbedded;
 
 struct _HTMLEngineClass {
-	GtkObjectClass parent_class;
-
-	HTMLFontManager font_manager [HTML_FONT_MANAGER_ID_N];
-
+	GObjectClass parent_class;
+	
 	void (* title_changed) (HTMLEngine *engine);
 	void (* set_base) (HTMLEngine *engine, const gchar *base);
 	void (* set_base_target) (HTMLEngine *engine, const gchar *base_target);
@@ -293,12 +292,14 @@ struct _HTMLEngineClass {
 
 
 /* Object construction.  */
-guint       html_engine_get_type      (void);
+GType       html_engine_get_type      (void);
 HTMLEngine *html_engine_new           (GtkWidget *);
 void        html_engine_realize       (HTMLEngine *engine,
 				       GdkWindow  *window);
 void        html_engine_unrealize     (HTMLEngine *engine);
 
+void      html_engine_saved     (HTMLEngine *e);
+gboolean  html_engine_is_saved  (HTMLEngine *e);
 
 /* Editability control.  */
 void      html_engine_set_editable  (HTMLEngine *e,
@@ -332,6 +333,8 @@ void  html_engine_draw                 (HTMLEngine *e,
 					gint        y,
 					gint        width,
 					gint        height);
+void  html_engine_expose               (HTMLEngine *e,
+					GdkEventExpose *event);
 void  html_engine_draw_background      (HTMLEngine *e,
 					gint        x,
 					gint        y,
@@ -420,6 +423,7 @@ void      html_engine_replace_spell_word_with  (HTMLEngine  *e,
 						const gchar *word);
 void      html_engine_set_language             (HTMLEngine  *e,
 						const gchar *language);
+const gchar *html_engine_get_language          (HTMLEngine *e);
 
 /* view size - for image size specified in percent */
 gint  html_engine_get_view_width   (HTMLEngine *e);
@@ -433,7 +437,7 @@ HTMLObject *html_engine_get_object_by_id    (HTMLEngine  *e,
 					     const gchar *id);
 
 HTMLEngine *html_engine_get_top_html_engine (HTMLEngine *e);
-void        html_engine_thaw_idle_reset     (HTMLEngine *e);
+void        html_engine_thaw_idle_flush     (HTMLEngine *e);
 
 /* class data */
 const gchar *html_engine_get_class_data        (HTMLEngine  *e,
@@ -458,7 +462,8 @@ void  html_engine_add_expose  (HTMLEngine *e,
 			       gint        x,
 			       gint        y,
 			       gint        width,
-			       gint        height);
+			       gint        height,
+			       gboolean    expose);
 void html_engine_redraw_selection (HTMLEngine *e);
 
 gboolean    html_engine_focus              (HTMLEngine       *e,
@@ -468,20 +473,9 @@ void        html_engine_set_focus_object   (HTMLEngine       *e,
 					    HTMLObject       *o);
 void        html_engine_draw_focus_object  (HTMLEngine       *e);
 
-void      html_engine_saved     (HTMLEngine *e);
-gboolean  html_engine_is_saved  (HTMLEngine *e);
-
 HTMLMap *html_engine_get_map  (HTMLEngine  *e,
 			       const gchar *name);
 
-HTMLFontManager *html_engine_gdk_font_manager           (HTMLEngine  *e);
-HTMLFontManager *html_engine_plain_font_manager         (HTMLEngine  *e);
-HTMLFontManager *html_engine_font_manager               (HTMLEngine  *e);
-HTMLFontManager *html_engine_font_manager_with_painter  (HTMLEngine  *e,
-							 HTMLPainter *p);
-HTMLFontManager *html_engine_class_gdk_font_manager     (void);
-HTMLFontManager *html_engine_class_plain_font_manager   (void);
-
 gboolean html_engine_selection_contains_object_type (HTMLEngine *e,
 						     HTMLType obj_type);
 gboolean html_engine_selection_contains_link        (HTMLEngine *e);
